@@ -4,8 +4,8 @@
 from debian.sid_options import *
 
 mpi = 'OPENMPI'
-mpi_include = '/usr/lib/' + arch.decode('UTF-8') + '/openmpi/include'
-mpi_lib = '/usr/lib/' + arch.decode('UTF-8') + '/openmpi/lib'
+mpi_include = '/usr/lib/' + arch + '/openmpi/include'
+mpi_lib = '/usr/lib/' + arch + '/openmpi/lib'
 mpi_prefix = [mpi_include,mpi_lib]
 
 cxx_extra=' -Wno-stringop-truncation'
